
package seabedexplorer;

import java.util.ArrayList;
import java.util.Random;
import java.util.Scanner;
import seabedexplorer.submersible.*;
import seabedexplorer.submersible.equipment.locationtracking.Location;
import seabedexplorer.submersible.state.states.*;
import seabedexplorer.util.submersible.*;

/**
 *
 * @author Stedos
 */
public class Main_State_Pattern {

    public static void main(String[] args) throws InterruptedException
    {
        /////////
        //Tests//
        /////////
        
        //Create scanner for pauses in demonstration.
        Scanner sc = new Scanner(System.in);
        
        //Generate random submersible (with all equipment attached)
        SubmersibleBuilder subBuilder = new SubmersibleBuilder(generateRandomSubType());
        subBuilder.addAll();
        Submersible sub = subBuilder.build();
        //Print out all submersibles
        System.out.println(sub.toString());
        System.out.println();
        System.out.println();
        System.out.println();
        
        //Pause until user presses enter (to temp pause)
        sc.nextLine();
        
        //Change states of submersibles to docked (should be as default, but this is a check)
        System.out.println();
        System.out.println(sub.getSubmersibleType() + ": ");
        sub.changeState(new DockedState());
        
        //Pause until user presses enter (to temp pause)
        sc.nextLine();
        
        //Move first submersible
        System.out.println(sub.getSubmersibleType() + ": ");
        sub.move(new Location(6, 4, -10));
        System.out.println();
        
        
        //Pause until user presses enter (to temp pause)
        sc.nextLine();
        
        //Print out sub types and states
        System.out.println();
        System.out.println(sub.getSubmersibleType());
        System.out.println(sub.getState().toString());
        
        
        
        //Data collection
        //Try collecting material data for each sub
        System.out.println();
        System.out.println(sub.collectMaterial());
        System.out.println(sub.toString());
        
        //Pause until user presses enter (to temp pause)
        sc.nextLine();
        
        //Print out states for all submersibles
        System.out.println();
        System.out.println("Sub is currently in state: " + sub.getState().toString());
        System.out.println(sub.toString());
        
        //Pause until user presses enter (to temp pause)
        sc.nextLine();
        
        //Collect water sample (shows water sample can't  be collected on a full inventory)
        System.out.println();
        sub.collectWater();
        System.out.println("Sub is currently in state: " + sub.getState().toString());
        
        //Pause until user presses enter (to temp pause)
        sc.nextLine();
        
        //Collect mapping sample (shows mapping data can be collected while inventory is full)
        System.out.println();
        sub.collectMappingData();
        System.out.println("Sub is currently in state: " + sub.getState().toString());
        
        
        //Pause until user presses enter (to temp pause)
        sc.nextLine();
        
        //Return to vessel
        System.out.println();
        sub.returnToVessel();
        
        //Pause until user presses enter (to temp pause)
        sc.nextLine();
        
        //Print out final states and finish
        System.out.println();
        System.out.println(sub.getSubmersibleType());
        System.out.println(sub.getState().toString());
    }
    
    
    private static SubmersibleType generateRandomSubType()
    {
        Random r = new Random();
        switch(r.nextInt(3))
        {
            case 0: return SubmersibleType.AUTOMATED_UNDERWATER_VEHICLE;
            case 1: return SubmersibleType.MANNED_SUBMERSIBLE;
            case 2: return SubmersibleType.REMOTE_OPERATED_VEHICLE;
        }
        return null;
        
    }
    
}
