
package seabedexplorer.data;

/**
 * IndexOfRefractionReading. Stores an angle of incidence, an angle of 
 * refraction, and an index of refraction. The former is inherent, the latter is
 * calculated, and the other is recorded.
 * 
 * @author Dan Lawrence
 */
public class IndexOfRefractionReading extends WaterReading {
    
    /**
     * The index of refraction.
     */
    double indexOfRefraction;
    
    /**
     * The angle of incidence, in degrees.
     */
    double angleOfIncidence;
    
    /**
     * The angle of refraction, in degrees.
     */
    double angleOfRefraction;
    
    /**
     * Constructor. Is the only way to set the values of the angles of incidence
     * and refraction. The index of refraction is calculated.
     * 
     * @param angleOfRefractionIn The angle of refraction, in degrees.
     * 
     * @param angleOfIncidenceIn The angle of incidence, in degrees.
     */
    public IndexOfRefractionReading(double angleOfRefractionIn, double angleOfIncidenceIn) {
        angleOfIncidence = angleOfIncidenceIn;
        angleOfRefraction = angleOfRefractionIn;
        
        try {
            indexOfRefraction = angleOfIncidence / angleOfRefraction;
        } catch (ArithmeticException e) {
            indexOfRefraction = 0;
        }
        
        System.out.println("Refractive index reading stored successfully.\n");
    }
    
    /**
     * Returns the angle of incidence, of the same data type it is stored as (double).
     */
    public double getAngleOfIncidence() {
        return angleOfIncidence;
    }
    
    /**
     * Returns the angle of refraction, of the same data type it is stored as (double).
     */
    public double getAngleOfRefraction() {
        return angleOfRefraction;
    }
    
    /**
     * Returns the index of refraction, of the same data type it is stored as (double).
     */
    public double getIndexOfRefraction() {
        return indexOfRefraction;
    }
    
    @Override
    public String toString() {
        String reading = "Refractive Index Reading:\n"
                       + "    Angle of Incidence: " + angleOfIncidence + "°\n"
                       + "    Recorded Angle of Refraction: " + angleOfRefraction + "°\n"
                       + "    Determined Refractive Index: ";
        
        if (indexOfRefraction == 0)
            reading += "Undefined";
        else
            reading += indexOfRefraction;
        
        reading += "\n";
        
        return reading;
    }
}
