package seabedexplorer.data;

/**
 * MaterialSample. Stores the mass, and volume of a material sample, as 
 * collected by a piece of material sampling equipment.
 * 
 * @author Dan Lawrence
 */
public class MaterialSample implements Data
{
    
    /**
     * Volume of the sample, in meters cubed. Is dependant entirely on the 
     * capacity of the sampler.
     */
    double volume;
    
    /**
     * Mass of the sample, in kilograms.
     */
    double mass;
    
    /**
     * Density of the sample, in kg/m³.
     */
    double density;
    
    /**
     * Constructor. Is the only way to set the values for mass and volume. The 
     * value of density is calculated, so cannot be set manually.
     * 
     * @param volumeIn Volume of the sample, in meters cubed. Is dependant entirely on the 
     * capacity of the sampler.
     * 
     * @param massIn Mass of the sample, in kilograms.
     */
    public MaterialSample(double volumeIn, double massIn) {
        volume = volumeIn;
        mass = massIn;
        
        density = mass/volume;
        
        System.out.println("Material sample collected successfully.\n");
    }
    
    /**
     * Returns the volume, of the same data type it is stored as (double).
     */
    public double getVolume() {
        return volume;
    }
    
    /**
     * Returns the mass, of the same data type it is stored as (double).
     */
    public double getMass() {
        return mass;
    }
    
    /**
     * Returns the density, of the same data type it is stored as (double).
     */
    public double getDensity() {
        return density;
    }
    
    @Override 
    public String toString() {
        return "Material sample:\n"
             + "    Volume of sample: " + volume + "m³\n"
             + "    Recorded mass of sample: " + mass + "kg\n"
             + "    Determined density of sample: " + density + "kg/m³\n";
    }
}
