
package seabedexplorer.data;

/**
 * SonarReading. Stores a response time, as recorded by a sonar 
 * emitter/receiver.
 * 
 * @author Dan Lawrence
 */
public class SonarReading extends TopographicalMapping {
    
    /**
     * The recorded response time, in milliseconds.
     */
    double responseTime;
   
    /**
     * Constructor. Is the only way to set a value for the response time 
     * reading.
     * 
     * @param responseTimeIn The response time, as recorded by the sonar 
     * receiver.
     */
    public SonarReading(double responseTimeIn) {
        responseTime = responseTimeIn;
        
        calculateDepth();
        
        System.out.println("Sonar depth reading stored successfully.\n");
    }

    @Override
    void calculateDepth() {
        depth = responseTime * 1.5;
    }
    
    /**
     * Returns the response time, of the same data type it is stored as (double)
     */
    public double getReading() {
        return responseTime;
    }

    @Override
    public String toString() {
        return "Sonar reading:\n"
            +  "    Response time: " + responseTime + "ms\n"
            +  "    Determined depth: " + depth + "m\n";
    }
}
