package seabedexplorer.observer;

import java.util.ArrayList;
import java.util.Collection;

/**
 * A Subject interface created to facilitate the implementation of the Observer design pattern between Vessels and Submersibles.
 * 
 * @author Dylan Currey
 * @since 01/11/18
 */
public interface Subject
{
    
    /**
     * An ArrayList containing all observers attached to the concrete subject.
     */
    Collection<Observer> listOfObservers = new ArrayList<>();
    
    /**
     * Attaches observers to the subject.
     * @param observer the <i>Observer</i> object to be attached.
     */
    public void attach(Observer observer);
    
    /**
     * Detaches observers from the subject
     * @param observer the <i>Observer</i> object to be detached
     */
    public void detach (Observer observer);
    
    /**
     * Updates all observers in <i>listOfObservers</i> with a command.
     * @param cmd the command sent.
     */
    public boolean updateObservers(String cmd);
    
}
