package seabedexplorer.submersible.equipment.datacollector.materialsampler;

import java.util.concurrent.ThreadLocalRandom;
import seabedexplorer.data.Data;
import seabedexplorer.data.MaterialSample;
import seabedexplorer.submersible.equipment.datacollector.DataCollector;

/**
 * DCMaterialSampler. Simulates the behaviour of a material sample of a 
 * specified volume being collected, and having its mass recorded.
 * 
 * @author Dan Lawrence
 */
public abstract class DCMaterialSampler implements DataCollector
{
    /**
     * The volume of the sample, in m³. Determined by the capacity of the 
     * equipment.
     */
    double volume;
    
    /**
     * Constructor. Used to transfer the capacity of the equipment into this 
     * class, so it can be passed into the reading.
     * @param volumeIn - The sample capacity of the equipment.
     */
    public DCMaterialSampler(double volumeIn) {
        volume = volumeIn;
    }
    
    @Override
    public Data performReading() {
        System.out.println("Collecting material sample, of volume " + volume + "m³...");
        
        double actualDensity = ThreadLocalRandom.current().nextDouble(0, 22500);
        double actualMass = actualDensity * volume;
        
        double mass;
        
        if (ThreadLocalRandom.current().nextInt(0, 10) == 0)
            mass = ThreadLocalRandom.current().nextDouble(0,25000);
        else
            mass = ThreadLocalRandom.current().nextDouble(0.9 * actualMass, 1.1 * actualMass);
        
        return new MaterialSample(volume,mass);
    }
    
}
