package seabedexplorer.submersible.equipment.datacollector.topographicalmapper;

import java.util.concurrent.ThreadLocalRandom;
import seabedexplorer.data.LaserReading;
import seabedexplorer.data.TopographicalMapping;

/**
 * DCLaser. Simulates the behaviour of a laser camera, with a specified distance
 * between the camera, and the emitter. An angle is recorded, and is used in a 
 * trigonometric function to calculate the depth of the seabed, at the point 
 * that the laser landed.
 * 
 * @author Dan Lawrence
 */
public class DCLaser implements DCTopographicalMapper
{
    /**
     * The distance between the camera, and the laser emitter, in meters.
     */
    double distance;
    
    /**
     * Constructor. Used to transfer the distance into this class, so it can be 
     * passed into the reading.
     * 
     * @param distanceIn The distance between the camera, and the laser emitter,
     * in meters.
     */
    public DCLaser(double distanceIn) {
        distance = distanceIn;
    }
    
    @Override
    public TopographicalMapping performReading()
    {
        System.out.println("Taking depth reading with laser camera, distance of "
                            + distance + "m between camera, and emitter...");
        
        double actualDepth = ThreadLocalRandom.current().nextDouble(0,10000);
        double actualAngle = (180/Math.PI) * Math.atan(distance / actualDepth);
        
        double angle;
        
        if (ThreadLocalRandom.current().nextInt(0, 10) == 0)
            angle = ThreadLocalRandom.current().nextDouble(0,90);
        else
            angle = ThreadLocalRandom.current().nextDouble(0.9 * actualAngle, 1.1 * actualAngle);
        
        return new LaserReading(angle,distance);
    }
    
}
