package seabedexplorer.submersible.state;

import seabedexplorer.submersible.Submersible;
import seabedexplorer.submersible.equipment.locationtracking.Location;

public interface SubmersibleState {

    /**
    *Passes the original Submersible object instance to the state, if it needs it.
    * @param  submersible The instance that wants to be passed.
    */
    public void submersibleInstance(Submersible submersible);
    
    //Movement methods

    /**
    *Moves object to a location.
    * @param  loc The Location of the target location.
    * @return Returns if the movement command was executed successfully.
    */
    public boolean move(Location loc);
    
    /**
    *Stops the movement of an object to a location.
    * @return Returns if the movement stop command was executed successfully.
    */
    public boolean stopMove();
    
    /**
    *Returns object back to vessel.
    * @return Returns if the object was returned to the vessel successfully.
    */
    public boolean returnToVessel();
    
    /**
    *Checks if the object can move.
    * @return Returns if the object is able to move.
    */
    public boolean canMove();
    
    //Collection methods
    
    /**
    *Collects water sample.
    * @return Returns if the water sample was collected successfully.
    */
    public boolean collectWater();
    
    /**
    *Collects material sample.
    * @return Returns if the material sample was collected successfully.
    */
    public boolean collectMaterial();
    
    /**
    *Collects material sample.
    * @return Returns if the material sample was collected successfully.
    */
    public boolean collectMappingData();
    
}
