package seabedexplorer.submersible.state.states;

import seabedexplorer.submersible.Submersible;
import seabedexplorer.submersible.equipment.locationtracking.Location;
import seabedexplorer.submersible.state.SubmersibleState;
import seabedexplorer.util.movement.MovementEmulation;

public class BusyMoveState implements SubmersibleState
{

    private Submersible subContext;
    private MovementEmulation ME;
    
    public BusyMoveState(MovementEmulation me)
    {
        ME = me;
    }
    
    @Override
    public boolean move(Location loc)
    {
        System.out.println("Currently moving, unable to handle another movement command.");
        return false;
    }
    
    @Override
    public boolean stopMove()
    {
        ME.stopMove();
        //Change state to Idle since movement has stopped.
        subContext.changeState(new IdleState());
        return true;
    }
    
    @Override
    public boolean canMove()
    {
        return false;
    }
    
    @Override
    public void submersibleInstance(Submersible submersible)
    {
        subContext = submersible;
    }
    
    @Override
    public String toString()
    {
        return "Busy (Movement in progress)";
    }

    @Override
    public boolean returnToVessel()
    {
        System.out.println("Unable to return to vessel while moving.");
        return false;
    }

    @Override
    public boolean collectWater()
    {
        System.out.println("Unable to collect water sample while moving.");
        return false;
    }

    @Override
    public boolean collectMaterial()
    {
        System.out.println("Unable to collect material sample while moving.");
        return false;
    }

    @Override
    public boolean collectMappingData()
    {
        System.out.println("Unable to collect mapping data while moving.");
        return false;
    }

}
