package seabedexplorer.submersible.state.states;

import seabedexplorer.submersible.Submersible;
import seabedexplorer.submersible.equipment.locationtracking.Location;
import seabedexplorer.submersible.state.SubmersibleState;
import seabedexplorer.util.movement.MovementEmulation;

public class DockedState implements SubmersibleState
{
    private Submersible subContext;
    private MovementEmulation ME;
    
    @Override
    public boolean move(Location loc)
    {
        subContext.changeState(new DeployState());
        ME = new MovementEmulation(subContext, loc);
        ME.move();
        //Wait for thread to finish
        try
        {
            ME.getThread().join();
        }
        catch (Exception e)
        {
            System.out.println("Failed to Join Thread.");
        }
        //Change state to idle after movement finishes.
        subContext.changeState(new IdleState());
        return true;
    }
    
    @Override
    public boolean stopMove()
    {
        System.out.println("Unable to stop moving while docked.");
        return false;
    }
    
    @Override
    public boolean canMove()
    {
        return true;
    } 
    
    @Override
    public void submersibleInstance(Submersible submersible)
    {
        subContext = submersible;
    }
    
    @Override
    public String toString()
    {
        return "Docked";
    }

    @Override
    public boolean returnToVessel()
    {
        System.out.println("Unable to return to dock while already docked.");
        return false;
    }

    @Override
    public boolean collectWater()
    {
        System.out.println("Unable to collect water sample while docked.");
        return false;
    }

    @Override
    public boolean collectMaterial()
    {
        System.out.println("Unable to collect material sample while docked.");
        return false;
    }

    @Override
    public boolean collectMappingData()
    {
        System.out.println("Unable to collect mapping data while docked.");
        return false;
    }

}
