package seabedexplorer.submersible.state.states;

import seabedexplorer.submersible.Submersible;
import seabedexplorer.submersible.equipment.locationtracking.Location;
import seabedexplorer.submersible.state.SubmersibleState;
import seabedexplorer.util.movement.MovementEmulation;

public class InventoryFullState implements SubmersibleState
{
    
    private Submersible subContext;
    private MovementEmulation ME;
    
    @Override
    public boolean move(Location loc)
    {
        System.out.println("Unable to move, inventory is full (return to the vessel to empty inventory)");
        return false;
    }
    
    @Override
    public boolean stopMove()
    {
        System.out.println("Not currently moving, cannot stop the movement.");
        return false;
    }
    
    @Override
    public boolean canMove()
    {
        return false;
    }
    
    @Override
    public void submersibleInstance(Submersible submersible)
    {
        subContext = submersible;
    }

    @Override
    public String toString()
    {
        return "Inventory Full";
    }

    @Override
    public boolean returnToVessel()
    {
        //Location of the vessel is implied 0, 0, 0, as this is where a sub starts.
        ME = new MovementEmulation(subContext, new Location(0, 0, 0));
        //Change context to BusyMoveState as the sub is moving
        subContext.changeState(new BusyMoveState(ME));
        ME.move();
        //Wait for thread to finish
        try
        {
            ME.getThread().join();
        }
        catch (Exception e)
        {
            System.out.println("Failed to Join Thread.");
        }
        //Change state to Docked
        subContext.changeState(new DockedState());
        return true;
    }

    @Override
    public boolean collectWater()
    {
        System.out.println("Unable to collect water sample while inventory is full.");
        return false;
    }

    @Override
    public boolean collectMaterial()
    {
        System.out.println("Unable to collect material sample while inventory is full.");
        return false;
    }

    @Override
    public boolean collectMappingData()
    {
        subContext.update("laser");
        subContext.update("sonar");
        return true;
    }
    
}
