
package seabedexplorer.util.movement;

import java.util.logging.Level;
import java.util.logging.Logger;
import seabedexplorer.submersible.Submersible;
import seabedexplorer.submersible.equipment.locationtracking.Location;
import seabedexplorer.submersible.state.states.BusyMoveState;
import seabedexplorer.submersible.state.states.IdleState;

public class ThreadMovement implements Runnable{
    
    
    private Submersible subm;
    private Location destinationLoc;
    //In this instance, speed is the amount of milliseconds (ticks) it takes for the Submersible to move one unit (for example, 1000 ms to move one unit in the x direction)
    private int speed;

    public ThreadMovement(Submersible sub, Location destinationLocLocal, int speedLocal)
    {
        subm = sub;
        destinationLoc = destinationLocLocal;
        speed = speedLocal;
    }

    @Override
    public void run()
    {         
        //Check if at destination location
        while (!atDestinationLocation(subm.getGPS().getCurrentLocation(), destinationLoc))
        {
            subm.getGPS().setCurrentLocation(calculateNextCheckpointLocation(subm.getGPS().getCurrentLocation(), destinationLoc));
            printLocation(subm.getGPS().getCurrentLocation());
        }
    }
    
    
    private Location calculateNextCheckpointLocation(Location currentLocation, Location destLoc)
    {
        
        //Thread pausing to emulate movement time
        try
        {
            Thread.sleep(speed);
        }
        catch (Exception e)
        {
            System.out.println(e);
        }
        
        Location loc = currentLocation;
        
        //Check X Coordinate
        if (loc.getPosX() < destLoc.getPosX())
        {
            loc.setPosX(loc.getPosX() + 1);
        }
        else if (loc.getPosX() > destLoc.getPosX())
        {
            loc.setPosX(loc.getPosX() - 1);
        }
        
        //Check Y Coordinate
        if (loc.getPosY() < destLoc.getPosY())
        {
            loc.setPosY(loc.getPosY() + 1);
        }
        else if (loc.getPosY() > destLoc.getPosY())
        {
            loc.setPosY(loc.getPosY() - 1);
        }
        
        //Check Z Coordinate
        if (loc.getPosZ() < destLoc.getPosZ())
        {
            loc.setPosZ(loc.getPosZ() + 1);
        }
        else if (loc.getPosZ() > destLoc.getPosZ())
        {
            loc.setPosZ(loc.getPosZ() - 1);
        }
        
        return loc;
    }
    
    private boolean atDestinationLocation(Location currentLocation, Location destLoc)
    {
        if ((currentLocation.getPosX() == destLoc.getPosX()) && (currentLocation.getPosY() == destLoc.getPosY()) && (currentLocation.getPosZ() == destLoc.getPosZ()))
        {
            return true;
        }
        return false;
    }
    
    private void printLocation(Location loc)
    {
        System.out.println("Location: " + loc);
    }

}
