package seabedexplorer.vessel;

import java.util.ArrayList;
import java.util.List;
import seabedexplorer.observer.Observer;
import seabedexplorer.observer.Subject;
import seabedexplorer.submersible.Submersible;

/**
 * Class representing the vessel controlling all attached submersibles.
 * Acts as subject in observer pattern
 * 
 * @author Dylan Currey
 */
public class Vessel implements Subject
{
    
    private List<Observer> listOfObservers = new ArrayList<>();

    /**
     * Constructor vessel class holding submersibles
     */
    public Vessel()
    {

    }
    
    @Override
    public void attach(Observer observer) {
        listOfObservers.add(observer);
    }

    @Override
    public void detach(Observer observer) {
        if(listOfObservers.contains(observer)){
            listOfObservers.remove(observer);
        }
    }

    @Override
    public boolean updateObservers(String cmd) {
        boolean result = false;
        for (Observer o : listOfObservers){
            result = o.update(cmd);
        }
        return result;
    }
    
    public int getNoSubmersibles() {
        return listOfObservers.size();
    }
    
    public Submersible getSubmersible(int num)
    {
        return (Submersible) listOfObservers.get(num);
    }
    
}
