package decorator_pattern_tests.submersible.equipment.waterreadings;

import static org.junit.Assert.*;
import org.junit.Test;
import seabedexplorer.data.Data;
import seabedexplorer.data.LaserReading;
import seabedexplorer.submersible.AUV;
import seabedexplorer.submersible.Submersible;
import seabedexplorer.submersible.equipment.locationtracking.Location;
import seabedexplorer.submersible.equipment.waterreadings.PH;
import seabedexplorer.submersible.state.SubmersibleState;
import seabedexplorer.submersible.state.states.DeployState;
import seabedexplorer.submersible.state.states.IdleState;

/**
 * PHTest
 * 
 * @author JLScott1999
 */
public class PHTest
{
    
    public PHTest()
    {
    }

    /**
     * Test of getSubmersible method, of class PH.
     */
    @Test
    public void testGetSubmersible()
    {
        System.out.println("getSubmersible");
        Submersible expResult = new AUV();
        Submersible instance = new PH(expResult);
        Submersible result = instance.getSubmersible();
        assertEquals(expResult, result);
    }

    /**
     * Test of collectData method, of class PH.
     */
    @Test
    public void testCollectData()
    {
        System.out.println("collectData");
        Submersible instance = new PH(new AUV());
        instance.collectData();
        assertTrue(instance.getData().size() > 0 && instance.getData().size() < 2);
    }
    
    /**
     * Test of addData method, of class PH.
     */
    @Test
    public void testAddData()
    {
        System.out.println("addData");
        Submersible instance = new PH(new AUV());
        Data data = new LaserReading(30, 1);
        instance.addData(data);
        assertTrue(instance.getData().contains(data));
    }

    /**
     * Test of changeState method, of class PH.
     */
    @Test
    public void testChangeState()
    {
        System.out.println("changeState");
        SubmersibleState state = new IdleState();
        Submersible instance = new PH(new AUV());
        instance.changeState(state);
        SubmersibleState result = instance.getState();
        assertEquals(state, result);
    }

    /**
     * Test of getState method, of class PH.
     */
    @Test
    public void testGetState()
    {
        System.out.println("getState");
        Submersible instance = new PH(new AUV());
        SubmersibleState expResult = new DeployState();
        instance.changeState(expResult);
        SubmersibleState result = instance.getState();
        assertEquals(expResult, result);
    }

   /**
     * Test of move method, of class PH.
     */
    @Test
    public void testMove()
    {
        System.out.println("move");
        Submersible instance = new PH(new AUV());
        Location expResult = new Location(1, 2, 1);
        instance.move(expResult);
        Location result = instance.getGPS().getCurrentLocation();
        assertEquals(expResult.toString(), result.toString());
    }

    /**
     * Test of stopMove method, of class PH.
     */
    @Test
    public void testStopMove()
    {
        System.out.println("stopMove");
        Submersible instance = new PH(new AUV());
        Location expResult = new Location();
        instance.stopMove();
        Location result = instance.getGPS().getCurrentLocation();
        assertEquals(expResult.toString(), result.toString());
    }

    /**
     * Test of canMove method, of class PH.
     */
    @Test
    public void testCanMove()
    {
        System.out.println("canMove");
        Submersible instance = new PH(new AUV());
        boolean expResult = true;
        boolean result = instance.canMove();
        assertEquals(expResult, result);
    }

    /**
     * Test of getSubmersibleType method, of class PH.
     */
    @Test
    public void testGetSubmersibleType()
    {
        System.out.println("getSubmersibleType");
        Submersible instance = new PH(new AUV());
        String expResult = "AUV (Automated Underwater Vehicle)";
        String result = instance.getSubmersibleType();
        assertEquals(expResult, result);
    }

    /**
     * Test of toString method, of class PH.
     */
    @Test
    public void testToString()
    {
        System.out.println("toString");
        Submersible instance = new PH(new AUV());
        String expResult = "Type: AUV (Automated Underwater Vehicle)\nState: Docked\nData:\nEquipment:\n    Water Readings - pH Reader";
        String result = instance.toString();
        assertEquals(expResult, result);
    }
    
}
